@@ -5,7 +5,7 @@ use base qw(Exporter);
 
 our @EXPORT = qw(get_ntp_time get_unix_time);
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub get_ntp_time
 {
@@ -28,23 +28,21 @@ sub get_unix_time
 
 =head1 NAME
 
-Net::NTPTime - Retrieve NTP and UNIX timestamp (unsigned integer) from an NTP server.
+Net::NTPTime
 
 =head1 SYNOPSIS
 
-	use Net::NTPTime;
-	
-	my $unix_time = get_unix_time;
-	
-	my $unix_time = get_unix_time('ntp.server.com');
-	
-	my $ntp_time = get_ntp_time;
-	
-	my $ntp_time = get_ntp_time('ntp.server.com');
+    use Net::NTPTime;
+    my $unix_time = get_unix_time;
+    my $unix_time = get_unix_time('ntp.server.com');
+    my $ntp_time = get_ntp_time;
+    my $ntp_time = get_ntp_time('ntp.server.com');
 
 =head1 DESCRIPTION
 
-Retrieves timestamps in NTP and UNIX formats from an NTP server.
+Retrieve NTP and UNIX timestamp (unsigned integer) from an NTP server.
+
+Pollutes the namespace with two functions: get_unix_time & get_ntp_time
 
 =head1 METHODS
 
@@ -64,13 +62,20 @@ You may include a specific NTP server to ping, or a default server will be used.
 
 1.01 - Bug fix (changed "require Socket" to "use Socket")
 
-=head1 The real credit goes to Tim Hogard for writing the code to do this. Thanks!
+1.02 - Fixed this POD document
 
-=head1 AUTHOR, COPYRIGHT, and LICENSE
+=head1 Author
 
-Copyright(C) 2009, phatWares, USA. All rights reserved.
+Brandon Bourret
+
+=head1 License
 
 Permission is granted to use this software under the same terms as Perl itself.
+
 Refer to the L<Perl Artistic|perlartistic> license for details.
 
-=cut
+=head1 Credits
+
+The real credit goes to Tim Hogard for writing the code to do this. Thanks!
+
+=cut
\ No newline at end of file
